@@ -25,16 +25,13 @@ def call_cnvs(frags, bin_size=100000, bin_bias_h5_fn=None, genome="hg19", method
     # Correct values
     if verbose: print("Correcting genome biases...")
     # Find distributed h5 reference bins
-    if bin_bias_h5_fn is None:
-        h5_file = genome + "_ucsc_bin" + str(bin_size) + ".h5"
-        if verbose: print("Reference genome:", genome)
-        bin_bias_h5_fn = os.path.join(frags.data_dir, h5_file)
-        if verbose: print("   Found bin_bias:", h5_file)
-        #genome_fn = os.path.join(self.data_dir, genome+"_chrom_sizes.txt")
-        #if self.verbose: print("   Found chrom_sizes:", genome+"_chrom_sizes.txt")
-        #centro_fn = os.path.join(self.data_dir, genome+"_centro.txt")
-        #if self.verbose: print("   Found centromeres:", genome+"_centro.txt")
-    bin_coverage = correct(bin_coverage, bin_bias_h5_fn, verbose=verbose)
+    #if bin_bias_h5_fn is None:
+        #h5_file = genome + "_ucsc_bin" + str(bin_size) + ".h5"
+        #if verbose: print("Reference genome:", genome)
+        #bin_bias_h5_fn = os.path.join(frags.data_dir, h5_file)
+        #if verbose: print("   Found bin_bias:", h5_file)
+        
+    bin_coverage = correct(bin_coverage, bin_bias_h5_fn, genome=genome, bin_size=bin_size, verbose=verbose)
 
     # Determine ratios
     if verbose: print("Normalizing...")
